@@ -1,4 +1,4 @@
-from phml import AST
+from phml.core import AST
 from phml.builder import p
 
 asts = {
